/* I tidigare exempel har drag-elementet endast varit ett div-element,
   utan några underelement. I detta exempel används drag-element som har
   underelement, bl.a. en img-tagg. Bilder är normalt dragbara i webbläsaren,
   så för att förhindra att endast bilden dras, om användaren tar tag i den,
   får man sätta draggable till false på img-taggarna. Det kan antingen göras
   direkt i HTML-koden med ett attribut i img-taggen, eller med JavaScript-kod
   för att lägga in draggable=false på img-taggarna. I detta exempel används
   den sistnämnda metoden. */
// --------------------------------------------------
// Globala variabler och konstanter

// --------------------------------------------------
// Initiering då webbsidan är inläst
function init() {
    let dragElems = document.querySelectorAll("#dragItems div");
    for (let i = 0; i < dragElems.length; i++) {
        dragElems[i].draggable = true;
        dragElems[i].addEventListener("dragstart", dragStart);
        dragElems[i].querySelector("img").draggable = false; // Enbart bilden får inte dras
    }
} // Slut init
window.addEventListener("load", init);
// --------------------------------------------------
// Hantera en drag-operation
function dragStart(e) {
    let dragElem = this;
    let dropElems = document.querySelectorAll("#dropZones div");
    dragElem.addEventListener("dragend", dragEnd);
    for (let i = 0; i < dropElems.length; i++) {
        dropElems[i].addEventListener("dragover", dropZone);
        dropElems[i].addEventListener("dragenter", dropZone);
        dropElems[i].addEventListener("dragleave", dropZone);
        dropElems[i].addEventListener("drop", dropZone);
    }
    // ----------
    // Avsluta drag-operationen
    function dragEnd(e) {
        dragElem.removeEventListener("dragend", dragEnd);
        for (let i = 0; i < dropElems.length; i++) {
            dropElems[i].removeEventListener("dragover", dropZone);
            dropElems[i].removeEventListener("dragenter", dropZone);
            dropElems[i].removeEventListener("dragleave", dropZone);
            dropElems[i].removeEventListener("drop", dropZone);
        }
    } // Slut dragEnd
    // ----------
    // Hantera händelser för drop zones
    function dropZone(e) {
        e.preventDefault();
        let dropElem = this;
        let color = dragElem.getAttribute("data-color");
        switch (e.type) {
            case "dragenter":
                dropElem.classList.add("hiliteDropZone");
                dropElem.style.outlineColor = color;
                break;
            case "dragleave":
                dropElem.classList.remove("hiliteDropZone");
                dropElem.style.outlineColor = "";
                break;
            case "drop":
                dropElem.classList.remove("hiliteDropZone");
                dropElem.style.outlineColor = "";
                dropElem.style.backgroundColor = color;
        } // Slut switch
    } // Slut dropZone
    // ----------
} // Slut dragStart
// --------------------------------------------------
