/* Exemplet visar hur man kan skapa en egen "skuggbild" som används då
   man drar ett element. Det visas också hur man kan dölja det element
   som man börjar dra, så att endast "skuggbilden" syns. */
// --------------------------------------------------
// Globala variabler och konstanter
let dragImg = [];	// Array med "skuggbilder" för drag-and-drop
// "Skuggbilderna" läses in, så att de finns i cache-minnet, då de sedan ska användas
dragImg[0] = new Image(); dragImg[0].src = "img/bucket2-red.png";
dragImg[1] = new Image(); dragImg[1].src = "img/bucket2-green.png";
dragImg[2] = new Image(); dragImg[2].src = "img/bucket2-blue.png";
// --------------------------------------------------
// Initiering då webbsidan är inläst
function init() {
    let dragElems = document.querySelectorAll("#dragItems div");
    for (let i = 0; i < dragElems.length; i++) {
        dragElems[i].draggable = true;
        dragElems[i].addEventListener("dragstart", dragStart);
        dragElems[i].querySelector("img").draggable = false;
        dragElems[i].setAttribute("data-ix", i); // Spara index i img-taggen
    }
} // Slut init
window.addEventListener("load", init);
// --------------------------------------------------
// Hantera en drag-operation
function dragStart(e) {
    let dragElem = this;
    let dropElems = document.querySelectorAll("#dropZones div");
    dragElem.addEventListener("dragend", dragEnd);
    for (let i = 0; i < dropElems.length; i++) {
        dropElems[i].addEventListener("dragover", dropZone);
        dropElems[i].addEventListener("dragenter", dropZone);
        dropElems[i].addEventListener("dragleave", dropZone);
        dropElems[i].addEventListener("drop", dropZone);
    }
    // Byt "skuggbild" och dölj bild som man tog tag i
    let ix = dragElem.getAttribute("data-ix");
    e.dataTransfer.setDragImage(dragImg[ix], 50, 30); // Ny skuggbild och förskjutning av muspekaren
    //dragElem.style.visibility = "hidden";
    dragElem.style.opacity = 0; // Dölj originalbilden
    // ----------
    // Avsluta drag-operationen
    function dragEnd(e) {
        dragElem.removeEventListener("dragend", dragEnd);
        for (let i = 0; i < dropElems.length; i++) {
            dropElems[i].removeEventListener("dragover", dropZone);
            dropElems[i].removeEventListener("dragenter", dropZone);
            dropElems[i].removeEventListener("dragleave", dropZone);
            dropElems[i].removeEventListener("drop", dropZone);
        }
        //dragElem.style.visibility = "visible";
        dragElem.style.opacity = 1; // Visa originalbilden igen
    } // Slut dragEnd
    // ----------
    // Hantera händelser för drop zones
    function dropZone(e) {
        e.preventDefault();
        let dropElem = this;
        let color = dragElem.getAttribute("data-color");
        switch (e.type) {
            case "dragenter":
                dropElem.classList.add("hiliteDropZone");
                dropElem.style.outlineColor = color;
                break;
            case "dragleave":
                dropElem.classList.remove("hiliteDropZone");
                dropElem.style.outlineColor = "";
                break;
            case "drop":
                dropElem.classList.remove("hiliteDropZone");
                dropElem.style.outlineColor = "";
                dropElem.style.backgroundColor = color;
        } // Slut switch
    } // Slut dropZone
    // ----------
} // Slut dragStart
// --------------------------------------------------
